@@ -1,6 +1,6 @@
 package Dancer::Plugin::ElasticModel;
 {
-  $Dancer::Plugin::ElasticModel::VERSION = '0.02';
+  $Dancer::Plugin::ElasticModel::VERSION = '0.03';
 }
 
 use strict;
@@ -9,27 +9,52 @@ use warnings;
 use Dancer qw(:syntax);
 use Dancer::Plugin;
 
-my $Model;
-
 #===================================
 register emodel => sub {
 #===================================
-    return $Model || _setup_model();
+    return _setup_model()->{model};
+};
+
+#===================================
+register eview => sub {
+#===================================
+    my $view = shift || '';
+    return _setup_model()->{views}{$view}
+        || die "Unknown view ($view)";
+};
+
+#===================================
+register edomain => sub {
+#===================================
+    my $domain = shift || '';
+    return _setup_model()->{model}->domain($domain);
 };
 
 #===================================
 sub _setup_model {
 #===================================
     my $settings = plugin_setting;
+    my $cache    = $settings->{_cache};
+    return $cache if $cache;
 
     my $model_class = $settings->{model}
         or die "Missing required setting (model)";
 
-    eval "require $model_class"
-        or die "Error loading model ($model_class): " . ( $@ || 'Unknown' );
+    my ( $res, $err ) = Dancer::ModuleLoader->load($model_class);
+    die "Error loading model ($model_class): $err"
+        unless $res;
 
     my $es = ElasticSearch->new( %{ $settings->{es} || {} } );
-    $Model = $model_class->new( es => $es );
+    my $model = $model_class->new( es => $es );
+
+    my $view_conf = $settings->{views} || {};
+    my %views = map { $_ => $model->view( %{ $view_conf->{$_} } ) }
+        keys %$view_conf;
+
+    return $settings->{_cache} = {
+        model => $model,
+        views => \%views,
+    };
 }
 
 register_plugin;
@@ -48,13 +73,17 @@ Dancer::Plugin::ElasticModel - Use Elastic::Model in your Dancer application
 
 =head1 VERSION
 
-version 0.02
+version 0.03
 
 =head1 SYNOPSIS
 
     use Dancer::Plugin::ElasticModel;
 
-    emodel->domain('myapp')->create( user => { name => 'Joe Bloggs' });
+    emodel->namespace('myapp')->index->create;
+
+    edomain('myapp')->create( user => { name => 'Joe Bloggs' });
+
+    my $results = eview('users)->search;
 
     my $results = emodel->view->search;
 
@@ -63,14 +92,6 @@ version 0.02
 Easy access to your L<Elastic::Model>-based application from within your
 L<Dancer> apps.
 
-=head1 METHODS
-
-=head2 emodel()
-
-When you C<use Dancer::Plugin::ElasticModel;> it will import a single method
-C<emodel()> which gives you access to the model that you have configured in
-your C<config.yml> file.
-
 =head1 CONFIG
 
     plugins:
@@ -79,9 +100,40 @@ your C<config.yml> file.
             es:
                 servers:    es1.mydomain.com:9200
                 transport:  http
+            views:
+                users:
+                    domain: myapp
+                    type:   user
 
-The C<model> should be the name of your model class (which uses L<Elastic::Model>).
-Any parameters specified in C<es> will be passed directly to L<ElasticSearch/new()>.
+The C<model> should be the name of your model class (which uses
+L<Elastic::Model>). Any parameters specified in C<es> will be passed
+directly to L<ElasticSearch/new()>.
+
+Optionally, you can predefine named L<views|Elastic::Model::View>, eg
+the C<users> view above is the equivalent of:
+
+    $view = $model->view( domain => 'myapp', type => 'user' );
+
+=head1 METHODS
+
+=head2 emodel()
+
+L</emodel()> gives you access to the model that you have configured in
+your C<config.yml> file.
+
+=head2 edomain()
+
+    $domain = edomain('mydomain');
+
+L</edomain()> is a shortcut for:
+
+    $domain = emodel->domain('mydomain');
+
+=head2 eview()
+
+    $users = eview('users')->search:
+
+Access the C<views> that you predefined in your L</CONFIG>.
 
 =head1 SEE ALSO
 
